@@ -1,4 +1,4 @@
-/* $Id: mal-conduit.c,v 1.9 2001/11/21 06:35:50 eskil Exp $ */
+/* $Id: mal-conduit.c,v 1.10 2003/01/26 22:38:14 toshok Exp $ */
 
 #include <glib.h>
 #include <gnome.h>
@@ -429,22 +429,15 @@ GnomePilotConduit *conduit_load_gpilot_conduit (GPilotPilot *pilot)
   
   gtk_object_set_data (GTK_OBJECT (retval), OBJ_DATA_CONFIG, cfg);
   gtk_object_set_data (GTK_OBJECT (retval), OBJ_DATA_OLDCONFIG, cfg2);
+
   
-  gtk_signal_connect (retval, 
-		     GNOME_PILOT_CONDUIT_STANDARD_SIGNAL_SYNCHRONIZE (synchronize),
-		     NULL);
-  gtk_signal_connect (retval, 
-		      GNOME_PILOT_CONDUIT_SIGNAL_CREATE_SETTINGS_WINDOW (create_settings_window),
-		      NULL);
-  gtk_signal_connect (retval, 
-		      GNOME_PILOT_CONDUIT_SIGNAL_DISPLAY_SETTINGS (display_settings),
-		      NULL);
-  gtk_signal_connect (retval,
-		      GNOME_PILOT_CONDUIT_SIGNAL_SAVE_SETTINGS (save_settings),
-		      NULL);
-  gtk_signal_connect (retval, 
-		      GNOME_PILOT_CONDUIT_SIGNAL_REVERT_SETTINGS (revert_settings),
-		      NULL);
+  gtk_signal_connect (retval, "synchronize", (GtkSignalFunc)synchronize, NULL);
+
+  gtk_signal_connect (retval, "create_settings_window", (GtkSignalFunc) create_settings_window, NULL);
+  gtk_signal_connect (retval, "display_settings", (GtkSignalFunc) display_settings, NULL);
+  gtk_signal_connect (retval, "save_settings", (GtkSignalFunc) save_settings, NULL);
+  gtk_signal_connect (retval, "revert_settings", (GtkSignalFunc) revert_settings, NULL);
+
   return GNOME_PILOT_CONDUIT (retval); 
 }
 
